@@ -1,7 +1,3 @@
-setcollapse <- function(x) {
-  paste0("{", paste0(x, collapse = ", "), "}")
-}
-
 #' @title Vectorised Logical requireNamespace
 #' @description Helper function for internal use. Vectorises the [requireNamespace] function and
 #' returns `TRUE` if all packages, `x`, are available and `FALSE` otherwise.
