@@ -1,10 +1,6 @@
 skip_if_no_pycox()
 
-set.seed(1)
-np <- reticulate::import("numpy")
-np$random$seed(1L)
-torch <- reticulate::import("torch")
-torch$manual_seed(1L)
+set_seed(1)
 
 test_that("silent", {
   expect_silent({fit <- pchazard(Surv(time, status) ~ ., data = rats[1:50, ], verbose = FALSE,
@@ -19,7 +15,11 @@ test_that("custom", {
 })
 
 test_that("auto sanity", {
-  sanity_check(model = "pchazard",
-               pars = list(frac = 0.3, activation = "relu", num_nodes = c(2L, 2L, 2L),
-                           dropout = 0.1, early_stopping = TRUE, epochs = 100L, batch_size = 32L))
+  sanity_check(
+    model = "pchazard",
+    pars = list(
+      activation = "relu", num_nodes = c(2L, 2L, 2L),
+      dropout = 0.1, epochs = 50L, batch_size = 32L
+    )
+  )
 })
